@@ -102,10 +102,14 @@ paste_cite (GtkWidget *mi, GtkHTMLControlData *cd)
 static void
 insert_link (GtkWidget *mi, GtkHTMLControlData *cd)
 {
+	char *filename;
+
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Insert"), ICONDIR "/insert-link-24.png");
+	filename = g_build_filename (ICONDIR, "insert-link-24.png", NULL);
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Insert"), filename);
+	g_free (filename);
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
 						   GTK_HTML_EDIT_PROPERTY_LINK, _("Link"),
@@ -263,10 +267,14 @@ prop_dialog (GtkWidget *mi, GtkHTMLControlData *cd)
 static void
 link_prop_dialog (GtkWidget *mi, GtkHTMLControlData *cd)
 {
+	char *filename;
+
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"), ICONDIR "/insert-link-24.png");
+	filename = g_build_filename (ICONDIR, "insert-link-24.png", NULL);
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"), filename);
+	g_free (filename);
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
 						   GTK_HTML_EDIT_PROPERTY_LINK, _("Link"),
@@ -527,6 +535,7 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 	    && !html_engine_spell_word_is_valid (e)) {
 		ADD_SEP;
 		ADD_ITEM (_("Check Word Spelling..."), spell_check_cb, NONE);
+		ADD_ITEM (_("Ignore Misspelled Word"), spell_ignore, NONE);		
 		if (get_n_languages (cd) > 1) {
 			gchar *lang;
 			gint i;
@@ -547,7 +556,6 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 			ADD_ITEM (_("Add Word to Dictionary"), spell_add, NONE);
 			g_object_set_data (G_OBJECT (menuitem), "abbrev", (gpointer) get_language (cd));
 		}
-		ADD_ITEM (_("Ignore Misspelled Word"), spell_ignore, NONE);
 	}
 
 	ADD_SEP;
