@@ -142,7 +142,7 @@ op_helper (HTMLObject *self, HTMLEngine *e, GList *from, GList *to, GList *left,
 	o    = (from) ? HTML_OBJECT (from->data) : clue->head;
 	last = (to)   ? HTML_OBJECT (to->data)   : clue->tail;
 
-	if ((o == NULL) && (last == NULL))
+	if ((o == NULL) || (last == NULL))
 		return cc;
 
 	if (HTML_IS_TEXT_SLAVE (last))
@@ -245,8 +245,8 @@ split (HTMLObject *self, HTMLEngine *e, HTMLObject *child, gint offset, gint lev
 	*left  = g_list_prepend (*left, self);
 	*right = g_list_prepend (*right, dup);
 
-	level--;
-	if (level)
+	level --;
+	if (level > 0)
 		html_object_split (self->parent, e, dup, 0, level, left, right);
 }
 
@@ -920,7 +920,6 @@ html_clue_remove_text_slaves (HTMLClue *clue)
 	}
 }
 
-
 gboolean
 html_clue_is_empty (HTMLClue *clue)
 {
